package Something;
use strict;
use Thing '-base';

field color => 'blue';

sub cool {}

1;
